@@ -1,6 +1,6 @@
 distNNeigh<-function(db){
   db<-as.matrix(db)
-  nn<-knearneigh(db,RANN=FALSE)
+  nn<-knearneigh(db,use_kd_tree=FALSE)
   nn<-knn2nb(nn)
   res<-unlist(nbdists(nn,db))
   res
